<?php
/**
 * Package for building SVG graphics.
 *
 * Copyright 2002-2007 The Horde Project (http://www.horde.org/)
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @package XML_SVG
 * @license http://www.fsf.org/copyleft/lgpl.html
 */
require_once 'XML/SVG/Animate.php';
require_once 'XML/SVG/Circle.php';
require_once 'XML/SVG/Defs.php';
require_once 'XML/SVG/Desc.php';
require_once 'XML/SVG/Document.php';
require_once 'XML/SVG/Element.php';
require_once 'XML/SVG/Ellipse.php';
require_once 'XML/SVG/FilterMergeNode.php';
require_once 'XML/SVG/Filter.php';
require_once 'XML/SVG/FilterPrimitive.php';
require_once 'XML/SVG/Fragment.php';
require_once 'XML/SVG/Group.php';
require_once 'XML/SVG/Image.php';
require_once 'XML/SVG/Line.php';
require_once 'XML/SVG/Marker.php';
require_once 'XML/SVG/Path.php';
require_once 'XML/SVG/Polygon.php';
require_once 'XML/SVG/Polyline.php';
require_once 'XML/SVG/RadialGradient.php';
require_once 'XML/SVG/Rect.php';
require_once 'XML/SVG/Stop.php';
require_once 'XML/SVG/Textpath.php';
require_once 'XML/SVG/Text.php';
require_once 'XML/SVG/Title.php';
require_once 'XML/SVG/Tref.php';
require_once 'XML/SVG/Tspan.php';
require_once 'XML/SVG/Use.php';

